pub enum MacaroonError {
InitializationError,
CryptoError(&'static str),
IncompleteMacaroon(&'static str),
IncompleteCaveat(&'static str),
DeserializationError(String),
CaveatNotSatisfied(String),
DischargeNotUsed,
InvalidSignature,
}Expand description
Represents all of the errors that can arise when creating, deserializing, or verifying macaroons.
Variants
InitializationError
Only raised by the initialize() function, when there is a problem
initializing the lower-level crypto library
CryptoError(&'static str)
Represents a runtime error in the lower-level cryptographic library, or situations like zero-length ciphertext.
IncompleteMacaroon(&'static str)
Can occur when constructing or deserializing a Macaroon and expected fields are not present.
IncompleteCaveat(&'static str)
Can occur when constructing or deserializing Caveat and expected fields are not present.
DeserializationError(String)
Represents a broad category of issues when parsing a macaroon token in any format.
CaveatNotSatisfied(String)
Arises when verifying a Macaroon, when it has any caveat not
satisfied by any “exact” or “general” satisfiers configured on the
Verifier. Indicates a failure to authenticate the macaroon.
DischargeNotUsed
Arises when verifying a Macaroon, with a set of discharges configured
on the verifier, and one or more are not used during the verification process. Indicates a
failure to authenticate the macaroon.
InvalidSignature
Arises when verifying a Macaroon, and the signature does not match
what is expected. Indicates a failure to authenticate the macaroon.